pub enum ExecutionStateManagerRequest {
GetExecutionStateDependencyToken {
responder: ExecutionStateManagerGetExecutionStateDependencyTokenResponder,
},
AddApplicationActivityDependency {
payload: ExecutionStateManagerAddApplicationActivityDependencyRequest,
responder: ExecutionStateManagerAddApplicationActivityDependencyResponder,
},
#[non_exhaustive] _UnknownMethod {
ordinal: u64,
control_handle: ExecutionStateManagerControlHandle,
method_type: MethodType,
},
}Expand description
A service for exposing execution state management capabilities.
Variants
GetExecutionStateDependencyToken
Gets the dependency token for the execution state power element. This will block if SAG is not fully initialized.
Fields
AddApplicationActivityDependency
Adds a dependency from the Application Activity power element to the target
power element identified by [dependency_token] at [power_level].
Be aware of the following client-side conditions:
- If SAG is not fully initialized, the call blocks until initialization is complete.
- The call may block as required by
fuchsia.power.broker/ElementControl.AddDependency, which at time of writing may callfuchsia.power.ElementControl.SetLevelon the associated power element.
Fields
#[non_exhaustive]_UnknownMethod
An interaction was received which does not match any known method.
Fields
This variant is marked as non-exhaustive
Non-exhaustive enum variants could have additional fields added in future. Therefore, non-exhaustive enum variants cannot be constructed in external crates and cannot be matched against.

control_handle: ExecutionStateManagerControlHandle
method_type: MethodTypeImplementations
Sourceimpl ExecutionStateManagerRequest
impl ExecutionStateManagerRequest
pub fn into_get_execution_state_dependency_token( self, ) -> Option<ExecutionStateManagerGetExecutionStateDependencyTokenResponder>
pub fn into_add_application_activity_dependency( self, ) -> Option<(ExecutionStateManagerAddApplicationActivityDependencyRequest, ExecutionStateManagerAddApplicationActivityDependencyResponder)>
Sourcepub fn method_name(&self) -> &'static str
pub fn method_name(&self) -> &'static str
Name of the method defined in FIDL