pub struct ExecutionStateManagerGetExecutionStateDependencyTokenResponder { /* private fields */ }Implementations
Sourceimpl ExecutionStateManagerGetExecutionStateDependencyTokenResponder
impl ExecutionStateManagerGetExecutionStateDependencyTokenResponder
Sourcepub fn send(self, payload: ExecutionState) -> Result<(), Error>
pub fn send(self, payload: ExecutionState) -> Result<(), Error>
Sends a response to the FIDL transaction.
Sets the channel to shutdown if an error occurs.
Sourcepub fn send_no_shutdown_on_err(
self,
payload: ExecutionState,
) -> Result<(), Error>
pub fn send_no_shutdown_on_err( self, payload: ExecutionState, ) -> Result<(), Error>
Similar to “send” but does not shutdown the channel if an error occurs.