pub struct ExecutionStateManagerMarker;Trait Implementations
Sourceimpl Clone for ExecutionStateManagerMarker
impl Clone for ExecutionStateManagerMarker
Sourcefn clone(&self) -> ExecutionStateManagerMarker
fn clone(&self) -> ExecutionStateManagerMarker
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ExecutionStateManagerMarker
impl Debug for ExecutionStateManagerMarker
Sourceimpl DiscoverableProtocolMarker for ExecutionStateManagerMarker
impl DiscoverableProtocolMarker for ExecutionStateManagerMarker
Sourceconst PROTOCOL_NAME: &'static str = <Self as ProtocolMarker>::DEBUG_NAME
const PROTOCOL_NAME: &'static str = <Self as ProtocolMarker>::DEBUG_NAME
The name of the protocol (to be used for service lookup and discovery).
Sourceimpl Hash for ExecutionStateManagerMarker
impl Hash for ExecutionStateManagerMarker
Sourceimpl Ord for ExecutionStateManagerMarker
impl Ord for ExecutionStateManagerMarker
Sourcefn cmp(&self, other: &ExecutionStateManagerMarker) -> Ordering
fn cmp(&self, other: &ExecutionStateManagerMarker) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for ExecutionStateManagerMarker
impl PartialEq for ExecutionStateManagerMarker
Sourcefn eq(&self, other: &ExecutionStateManagerMarker) -> bool
fn eq(&self, other: &ExecutionStateManagerMarker) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for ExecutionStateManagerMarker
impl PartialOrd for ExecutionStateManagerMarker
Sourceimpl ProtocolMarker for ExecutionStateManagerMarker
impl ProtocolMarker for ExecutionStateManagerMarker
Sourceconst DEBUG_NAME: &'static str = "fuchsia.power.system.ExecutionStateManager"
const DEBUG_NAME: &'static str = "fuchsia.power.system.ExecutionStateManager"
The name of the protocol suitable for debug purposes. Read more
Sourcetype Proxy = ExecutionStateManagerProxy
type Proxy = ExecutionStateManagerProxy
The type of the structure against which FIDL requests are made.
Queries made against the proxy are sent to the paired
ServerEnd.Sourcetype RequestStream = ExecutionStateManagerRequestStream
type RequestStream = ExecutionStateManagerRequestStream
The type of the stream of requests coming into a server.
Sourcetype SynchronousProxy = ExecutionStateManagerSynchronousProxy
type SynchronousProxy = ExecutionStateManagerSynchronousProxy
The type of the structure against which thread-blocking FIDL requests are made.
Queries made against the proxy are sent to the paired
ServerEnd.impl Copy for ExecutionStateManagerMarker
impl Eq for ExecutionStateManagerMarker
impl StructuralPartialEq for ExecutionStateManagerMarker