pub struct ExecutionStateManagerProxy { /* private fields */ }Implementations
Sourceimpl ExecutionStateManagerProxy
impl ExecutionStateManagerProxy
Sourcepub fn new(channel: AsyncChannel) -> Self
pub fn new(channel: AsyncChannel) -> Self
Create a new Proxy for fuchsia.power.system/ExecutionStateManager.
Sourcepub fn take_event_stream(&self) -> ExecutionStateManagerEventStream
pub fn take_event_stream(&self) -> ExecutionStateManagerEventStream
Get a Stream of events from the remote end of the protocol.
Panics
Panics if the event stream was already taken.
Sourcepub fn get_execution_state_dependency_token(
&self,
) -> QueryResponseFut<ExecutionState, DefaultFuchsiaResourceDialect>
pub fn get_execution_state_dependency_token( &self, ) -> QueryResponseFut<ExecutionState, DefaultFuchsiaResourceDialect>
Gets the dependency token for the execution state power element. This will block if SAG is not fully initialized.
Sourcepub fn add_application_activity_dependency(
&self,
payload: ExecutionStateManagerAddApplicationActivityDependencyRequest,
) -> QueryResponseFut<ExecutionStateManagerAddApplicationActivityDependencyResult, DefaultFuchsiaResourceDialect>
pub fn add_application_activity_dependency( &self, payload: ExecutionStateManagerAddApplicationActivityDependencyRequest, ) -> QueryResponseFut<ExecutionStateManagerAddApplicationActivityDependencyResult, DefaultFuchsiaResourceDialect>
Adds a dependency from the Application Activity power element to the target
power element identified by [dependency_token] at [power_level].
Be aware of the following client-side conditions:
- If SAG is not fully initialized, the call blocks until initialization is complete.
- The call may block as required by
fuchsia.power.broker/ElementControl.AddDependency, which at time of writing may callfuchsia.power.ElementControl.SetLevelon the associated power element.