pub struct ExecutionStateManagerSynchronousProxy { /* private fields */ }Implementations
Sourceimpl ExecutionStateManagerSynchronousProxy
impl ExecutionStateManagerSynchronousProxy
pub fn new(channel: Channel) -> Self
pub fn into_channel(self) -> Channel
Sourcepub fn wait_for_event(
&self,
deadline: MonotonicInstant,
) -> Result<ExecutionStateManagerEvent, Error>
pub fn wait_for_event( &self, deadline: MonotonicInstant, ) -> Result<ExecutionStateManagerEvent, Error>
Waits until an event arrives and returns it. It is safe for other threads to make concurrent requests while waiting for an event.
Sourcepub fn get_execution_state_dependency_token(
&self,
___deadline: MonotonicInstant,
) -> Result<ExecutionState, Error>
pub fn get_execution_state_dependency_token( &self, ___deadline: MonotonicInstant, ) -> Result<ExecutionState, Error>
Gets the dependency token for the execution state power element. This will block if SAG is not fully initialized.
Sourcepub fn add_application_activity_dependency(
&self,
payload: ExecutionStateManagerAddApplicationActivityDependencyRequest,
___deadline: MonotonicInstant,
) -> Result<ExecutionStateManagerAddApplicationActivityDependencyResult, Error>
pub fn add_application_activity_dependency( &self, payload: ExecutionStateManagerAddApplicationActivityDependencyRequest, ___deadline: MonotonicInstant, ) -> Result<ExecutionStateManagerAddApplicationActivityDependencyResult, Error>
Adds a dependency from the Application Activity power element to the target
power element identified by [dependency_token] at [power_level].
Be aware of the following client-side conditions:
- If SAG is not fully initialized, the call blocks until initialization is complete.
- The call may block as required by
fuchsia.power.broker/ElementControl.AddDependency, which at time of writing may callfuchsia.power.ElementControl.SetLevelon the associated power element.